pywws.TimeZone — pywws 12.12_e27456b documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 12.12_e27456b documentation »
- Python programs and modules »

# pywws.TimeZone

## Introduction

This module provides two `datetime.tzinfo` objects representing UTC and local time zones. These are used to convert timestamps to and from UTC and local time. The weather station software stores data with UTC timestamps, to avoid problems with daylight savings time, but the template and plot programs output data with local times.

The module is copied directly from the `datetime.tzinfo` module documentation.

## Detailed API

Provide a couple of datetime.tzinfo() objects representing local time and UTC.

Copied directly from the datetime module documentation.

Classes

`LocalTimezone` | Local time
`UTC` | UTC

class `pywws.TimeZone.` `UTC`

  UTC

  `utcoffset`(dt)
  `tzname`(dt)
  `dst`(dt)

class `pywws.TimeZone.` `LocalTimezone`

  Local time

  `utcoffset`(dt)
  `dst`(dt)
  `tzname`(dt)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 12.12_e27456b documentation »
- Python programs and modules »